<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.1">
<context>
    <name>AppearanceWidget</name>
    <message>
        <location filename="../PAppearanceWidget.ui" line="14"/>
        <source>Appearance</source>
        <translation>Изглед</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="25"/>
        <source>PageEdit</source>
        <translation>ЕдиторСтранице</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="31"/>
        <location filename="../PAppearanceWidget.ui" line="263"/>
        <source>Fonts:</source>
        <translation>Фонтови:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="40"/>
        <source>If no font is specified in the CSS for your page, the following font will be used to display within PageEdit. These fonts will not be used in your actual ebook.</source>
        <translation>Ако CSS за вашу страну не наводи фонт, овај фонт ће да се користи за приказ унутар програма ЕдиторСтранице. Ови фонтови неће бити коришћени у вашим стварним е-књигама.</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="70"/>
        <source>Default font size to be used for PageEdit
if no font-size specified in your CSS</source>
        <translation>Подразумевана величина фонта која се користи за PageEdit
ако font-size није наведен у вашем CSS</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="74"/>
        <location filename="../PAppearanceWidget.ui" line="323"/>
        <source>Font Size:</source>
        <translation>Величина фонта:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="81"/>
        <source>Default font family to be used for PageEdit
if no font-family specified in your CSS</source>
        <translation>Подразумевана фамилија фонтова која се користи за PageEdit
ако font-family није наведен у вашем CSS</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="85"/>
        <source>Standard:</source>
        <translation>Стандардни:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="108"/>
        <source>Default font family to be used for PageEdit
if a serif font-family specified in your CSS</source>
        <translation>Подразумевана фамилија фонтова која се користи за PageEdit
ако је серифна font-family наведена у вашем CSS</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="112"/>
        <source>Serif:</source>
        <translation>Серифни:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="125"/>
        <source>Default font family to be used for PageEdit
if a sans-serif font-family specified in your CSS</source>
        <translation>Подразумевана фамилија фонтова која се користи за PageEdit
ако је бесерифна font-family наведена у вашем CSS</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="129"/>
        <source>Sans-Serif:</source>
        <translation>Бесерифни:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="156"/>
        <source>Make PageEdit simulate a dark appearance in dark mode</source>
        <translation>Нека PageEdit симулира тамни изглед у тамном режиму</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="181"/>
        <source>Main UI</source>
        <translation>Главни КИ</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="187"/>
        <source>Main Menu Icon Size:</source>
        <translation>Величина иконе главног менија</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="193"/>
        <source>Adjust the size of the icons in the main menu.</source>
        <translation>Подеси величину икона у главном менију</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="231"/>
        <source>High DPI Setting:</source>
        <translation>Поставка високе густине пиксела:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="240"/>
        <source>(Needs PageEdit Restart)</source>
        <translation>(неопходно поновно покретање програма PageEdit)</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="269"/>
        <source>UI Font:</source>
        <translation>КИ фонт</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="279"/>
        <source>Change the font used by PageEdit&apos;s menus, buttons, etc...</source>
        <translation>Мења фонт који програм PageEdit користи за меније, дугмиће, итд...</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="282"/>
        <source>Change Font (Needs PageEdit Restart)</source>
        <translation>Измена фонта (неопходно поновно покретање програма PageEdit)</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="306"/>
        <source>Insert Special Characters:</source>
        <translation>Уметни специјалне карактере:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="320"/>
        <source>Font size to be used for Insert Special Characters window</source>
        <translation>Величина фонта у прозору за уметање специјалних карактера </translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="353"/>
        <source>Font family to be used for Insert Special Characters window</source>
        <translation>Породица фонтова која се користи у прозору за уметање специјалних карактера</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="356"/>
        <source>Standard Font:</source>
        <translation>Стандардни фонт:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="423"/>
        <source>Reset all fonts and colors to the default values</source>
        <translation>Поставља све фонтове и боје на подразумеване вредности</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="426"/>
        <source>Reset All</source>
        <translation>Ресетуј све</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="49"/>
        <location filename="../AppearanceWidget.cpp" line="50"/>
        <source>Detect</source>
        <translation>Детектуј</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="49"/>
        <location filename="../AppearanceWidget.cpp" line="52"/>
        <source>On</source>
        <translation>Укљ.</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="49"/>
        <location filename="../AppearanceWidget.cpp" line="54"/>
        <source>Off</source>
        <translation>Искљ.</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="50"/>
        <source>Detect whether any high dpi scaling should take place.</source>
        <translation>Детектује да ли је потребно скалирање услед високе густине пиксела.</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="51"/>
        <source>Defers to any Qt environment variables that are set to control high dpi behavior.</source>
        <translation>Преусмерава на евентуално постављене Qt променљиве окружења за контролу понашања код високе густине пиксела.</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="52"/>
        <source>Turns on high dpi scaling and ignores any Qt environment variables</source>
        <translation>Укључује скалирање за високу густину пиксела и игнорише евентуалне Qt променљиве окружења</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="53"/>
        <source>that are set controlling high dpi behavior.</source>
        <translation>које су постављене за контролу понашања код високе густине пиксела.</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="54"/>
        <source>Turns off high dpi scaling regardless if any Qt environment</source>
        <translation>Искључује скалирање за високу густину пиксела без обзира на евентуалне Qt</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="55"/>
        <source>variables controlling high dpi behavior are set.</source>
        <translation>променљиве окружења које контролишу понашање за високу густину пиксела.</translation>
    </message>
</context>
<context>
    <name>GeneralSettings</name>
    <message>
        <location filename="../PGeneralSettings.ui" line="14"/>
        <source>General Settings</source>
        <translation>Општа подешавања</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="37"/>
        <source>You must restart PageEdit after changing the User Interface language.

If a translation for specific word or phrase is not available it will be displayed in English.</source>
        <translation>Морате поново да покренете ЕдиторСтранице после промене језика корисничког интерфејса.

Ако превод за поједину реч или фразу није доступан, биће приказан на енглеском.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="42"/>
        <source>User Interface Language:</source>
        <translation>Језик корисничког сучеља:</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="74"/>
        <source>Select from installed spellcheck dictionaries.</source>
        <translation>Изаберите један од инсталираних речника за проверу правописа.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="77"/>
        <source>Spellcheck Dictionary:</source>
        <translation>Речник провере правописа:</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="119"/>
        <source>Determine if html files are allowed to access non-multimedia remote resources.</source>
        <translation>Одредите да ли је html датотекама дозвољено да приступају не-мултимедијалним удаљеним ресурсима.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="122"/>
        <source> Control access by html files to non-multimedia remote resources.</source>
        <translation>Контрола приступа html датотекама не-мултимедијалним удаљеним ресурсима.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="131"/>
        <source>Check to allow html files to access non-multimedia remote resources.</source>
        <translation>Штиклирајте како бисте html датотекама дозволили приступ не-мултимедијалним удаљеним ресурсима.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="134"/>
        <source>Html files may access all remote resources types.</source>
        <translation>Html датотеке могу да приступе свим типовима удаљених ресурса.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="161"/>
        <source>Determine if javascript is allowed to be used by html files</source>
        <translation>Одредите да ли html датотеке могу да користе јаваскрипт</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="164"/>
        <source> Control use of javascript by html files.</source>
        <translation>Контрола коришћења јаваскрипта у html датотекама</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="173"/>
        <source>Check to allow html files to use javascript.</source>
        <translation>Штиклирајте да дозволите html датотекама коришћење јаваскрипта</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="176"/>
        <source>Html files may use javascript.</source>
        <translation>Html фајлови могу да користе јаваскрипт.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="204"/>
        <source>Choose how you would like PageEdit to handle the use of multiple white space characters during editing.</source>
        <translation>Изаберите како бисте желели да ЕдиторСтранице обрађује употребу вишеструких празних карактера током уређивања..</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="207"/>
        <source>Handle multiple white space layout using:</source>
        <translation>Обради распоред вишеструких празних карактера помоћу:</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="213"/>
        <source>Use CSS white-space: pre-wrap</source>
        <translation>Употреби CSS white-space: pre-wrap</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="216"/>
        <source>css white-space: pre-wrap</source>
        <translation>css white-space: pre-wrap</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="226"/>
        <source>Use non-breaking spaces as needed</source>
        <translation>Употреби по потреби размаке који не могу да се преломе</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="229"/>
        <source>non-breaking spaces as needed</source>
        <translation>размаци без прелома по потреби</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="257"/>
        <source>Determine if Prettify is used when saving</source>
        <translation>Одређује да ли се приликом чувања користи Prettify</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="260"/>
        <source> Use Prettify to reformat the xhtml when saving.</source>
        <translation>Употреби Prettify за реформатирање xhtml приликом чувања.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="269"/>
        <source>Check to reformat with Prettify when saving xhtml files.</source>
        <translation>Штиклирајте да се уради реформатирање помоћу Prettify када се чувају xhtml датотеке.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="272"/>
        <source>Use Prettify to reformat xhtml when saving.</source>
        <translation>Употреби Prettify да реформатираш xhtml приликом чувања.</translation>
    </message>
</context>
<context>
    <name>Inspector</name>
    <message>
        <location filename="../Inspector.cpp" line="74"/>
        <source>Inspect Page or Element</source>
        <translation>Прегледајте страницу или елемент</translation>
    </message>
    <message>
        <location filename="../Inspector.cpp" line="156"/>
        <source>The Inspector functionality is not supported before Qt 5.11</source>
        <translation>Функционалност Инспектора није подржана пре Qt 5.11</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main.ui" line="15"/>
        <location filename="../MainWindow.cpp" line="1012"/>
        <location filename="../MainWindow.cpp" line="1073"/>
        <location filename="../MainWindow.cpp" line="1764"/>
        <location filename="../MainWindow.cpp" line="1777"/>
        <location filename="../MainWindow.cpp" line="1783"/>
        <location filename="../MainWindow.cpp" line="1797"/>
        <location filename="../MainWindow.cpp" line="1810"/>
        <location filename="../MainWindow.cpp" line="1818"/>
        <location filename="../MainWindow.cpp" line="1873"/>
        <location filename="../MainWindow.cpp" line="1960"/>
        <source>PageEdit</source>
        <translation>ЕдиторСтранице</translation>
    </message>
    <message>
        <location filename="../main.ui" line="62"/>
        <source>&amp;File</source>
        <translation>&amp;Датотека</translation>
    </message>
    <message>
        <location filename="../main.ui" line="75"/>
        <source>&amp;Edit</source>
        <translation>&amp;Уређивање</translation>
    </message>
    <message>
        <location filename="../main.ui" line="88"/>
        <source>&amp;Find</source>
        <translation>&amp;Пронађи</translation>
    </message>
    <message>
        <location filename="../main.ui" line="95"/>
        <source>&amp;Insert</source>
        <translation>&amp;Уметање</translation>
    </message>
    <message>
        <location filename="../main.ui" line="110"/>
        <source>For&amp;mat</source>
        <translation>Фор&amp;мат</translation>
    </message>
    <message>
        <location filename="../main.ui" line="115"/>
        <source>&amp;Heading</source>
        <translation>&amp;Заглавље</translation>
    </message>
    <message>
        <location filename="../main.ui" line="130"/>
        <source>C&amp;hange Case</source>
        <translation>И&amp;змени величину слова</translation>
    </message>
    <message>
        <location filename="../main.ui" line="160"/>
        <source>&amp;View</source>
        <translation>&amp;Приказ</translation>
    </message>
    <message>
        <location filename="../main.ui" line="169"/>
        <source>Inspector</source>
        <translation>Инспектор</translation>
    </message>
    <message>
        <location filename="../main.ui" line="185"/>
        <source>File</source>
        <translation>Датотека</translation>
    </message>
    <message>
        <location filename="../main.ui" line="199"/>
        <source>Edit</source>
        <translation>Уреди</translation>
    </message>
    <message>
        <location filename="../main.ui" line="217"/>
        <location filename="../main.ui" line="1157"/>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <location filename="../main.ui" line="230"/>
        <source>Insert</source>
        <translation>Уметање</translation>
    </message>
    <message>
        <location filename="../main.ui" line="249"/>
        <source>Inspect</source>
        <translation>Прегледање</translation>
    </message>
    <message>
        <location filename="../main.ui" line="262"/>
        <location filename="../main.ui" line="1106"/>
        <source>Find</source>
        <translation>Пронађи</translation>
    </message>
    <message>
        <location filename="../main.ui" line="275"/>
        <source>Heading</source>
        <translation>Заглавље</translation>
    </message>
    <message>
        <location filename="../main.ui" line="289"/>
        <source>set Heading Level of Selected Text</source>
        <translation>постави ниво наслова за изабрани текст</translation>
    </message>
    <message>
        <location filename="../main.ui" line="303"/>
        <source>Change Case</source>
        <translation>Измена величине слова</translation>
    </message>
    <message>
        <location filename="../main.ui" line="319"/>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <location filename="../main.ui" line="337"/>
        <source>Align</source>
        <translation>Положај</translation>
    </message>
    <message>
        <location filename="../main.ui" line="353"/>
        <source>Indent</source>
        <translation>Увлачење</translation>
    </message>
    <message>
        <location filename="../main.ui" line="367"/>
        <source>Navigate</source>
        <translation>Навигација</translation>
    </message>
    <message>
        <location filename="../main.ui" line="377"/>
        <source>Navigation List</source>
        <translation>Листа за навигацију</translation>
    </message>
    <message>
        <location filename="../main.ui" line="393"/>
        <source>&amp;Save</source>
        <translation>&amp;Сачувај</translation>
    </message>
    <message>
        <location filename="../main.ui" line="396"/>
        <source>Save the current file.</source>
        <translation>Сачувај текућу датотеку.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="399"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../main.ui" line="409"/>
        <source>&amp;Print</source>
        <translation>&amp;Штампај</translation>
    </message>
    <message>
        <location filename="../main.ui" line="412"/>
        <source>Print the current Page.</source>
        <translation>Штампа текућу страницу.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="415"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../main.ui" line="421"/>
        <source>Save &amp;As...</source>
        <translation>Сачувај &amp;као...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="424"/>
        <source>Save the current file with a different filename.</source>
        <translation>Сачувај текућу датотеку под другим именом.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="427"/>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <location filename="../main.ui" line="437"/>
        <source>Cu&amp;t</source>
        <translation>Ис&amp;еци</translation>
    </message>
    <message>
        <location filename="../main.ui" line="440"/>
        <source>Cuts the selected text from the document and puts it on the clipboard.</source>
        <translation>Исеца изабрани текст из документа и ставља га у клипборд.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="450"/>
        <source>&amp;Paste</source>
        <translation>&amp;Налепи</translation>
    </message>
    <message>
        <location filename="../main.ui" line="453"/>
        <source>Pastes the content from the clipboard into the file.</source>
        <translation>Налепљује садржај клипборда у датотеку.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="463"/>
        <source>&amp;Undo</source>
        <translation>&amp;Опозови</translation>
    </message>
    <message>
        <location filename="../main.ui" line="466"/>
        <source>Reverts the changes of the previous operation.</source>
        <translation>Поништава промене које је начинила претходна операција.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="469"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../main.ui" line="479"/>
        <source>&amp;Redo</source>
        <translation>&amp;Претходно</translation>
    </message>
    <message>
        <location filename="../main.ui" line="482"/>
        <source>Restores the changes reverted by the previous Undo action.</source>
        <translation>Поново примењује промене које је поништила претходна Опозови акција.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="485"/>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <location filename="../main.ui" line="495"/>
        <source>&amp;Copy</source>
        <translation>&amp;Копирај</translation>
    </message>
    <message>
        <location filename="../main.ui" line="498"/>
        <source>Copies the selected text and puts it on the clipboard.</source>
        <translation>Копира изабрани текст и ставља га у клипборд.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="511"/>
        <source>Align &amp;Left</source>
        <translation>Положај &amp;лево</translation>
    </message>
    <message>
        <location filename="../main.ui" line="514"/>
        <source>Align the paragraph to the left.</source>
        <translation>Поравнава пасус лево.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="528"/>
        <source>Align &amp;Right</source>
        <translation>Положај &amp;десно</translation>
    </message>
    <message>
        <location filename="../main.ui" line="531"/>
        <source>Align the paragraph to the right.</source>
        <translation>Поравнава пасус десно</translation>
    </message>
    <message>
        <location filename="../main.ui" line="544"/>
        <source>&amp;Center</source>
        <translation>&amp;Центрирај</translation>
    </message>
    <message>
        <location filename="../main.ui" line="547"/>
        <source>Center the paragraph.</source>
        <translation>Центрира пасус.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="550"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../main.ui" line="563"/>
        <source>&amp;Justify</source>
        <translation>&amp;Поравнај обострано</translation>
    </message>
    <message>
        <location filename="../main.ui" line="566"/>
        <source>Align the paragraph to both the left and right margins.</source>
        <translation>Поравнава пасус обострано, и са левом и са десном маргином.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="569"/>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <location filename="../main.ui" line="582"/>
        <source>&amp;Bold</source>
        <translation>&amp;Подебљано</translation>
    </message>
    <message>
        <location filename="../main.ui" line="585"/>
        <source>Make the selected text bold.</source>
        <translation>Поставља приказ изабраног текста подебљаним словима.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="588"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../main.ui" line="601"/>
        <source>&amp;Italic</source>
        <translation>&amp;Курзив</translation>
    </message>
    <message>
        <location filename="../main.ui" line="604"/>
        <source>Make the selected text italic.</source>
        <translation>Поставља приказ изабраног текста курзивом.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="607"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../main.ui" line="617"/>
        <source>&amp;Open...</source>
        <translation>&amp;Отвори...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="620"/>
        <source>Open a file from disk.</source>
        <translation>Отвара датотеку са диска.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="623"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../main.ui" line="636"/>
        <source>&amp;Underline</source>
        <translation>&amp;Подвучено</translation>
    </message>
    <message>
        <location filename="../main.ui" line="639"/>
        <source>Underline the selected text.</source>
        <translation>Подвлачи изабрани текст.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="642"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../main.ui" line="652"/>
        <source>&amp;Lowercase</source>
        <translation>&amp;Мала слова</translation>
    </message>
    <message>
        <location filename="../main.ui" line="655"/>
        <source>Set selected text to lowercase.</source>
        <translation>Пребацује изабрани текст у мала слова.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="658"/>
        <source>Alt+L</source>
        <translation>Alt+L</translation>
    </message>
    <message>
        <location filename="../main.ui" line="668"/>
        <source>&amp;Uppercase</source>
        <translation>&amp;Велика слова</translation>
    </message>
    <message>
        <location filename="../main.ui" line="671"/>
        <source>Set selected text to uppercase.</source>
        <translation>Пребацује изабрани текст у велика слова.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="674"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../main.ui" line="684"/>
        <source>&amp;Titlecase</source>
        <translation>&amp;Почетна слова</translation>
    </message>
    <message>
        <location filename="../main.ui" line="687"/>
        <source>Capitalize the first letter of each word selected.</source>
        <translation>Капитализује прво слово сваке изабране речи.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="697"/>
        <source>&amp;Capitalize</source>
        <translation>&amp;Као реченица</translation>
    </message>
    <message>
        <location filename="../main.ui" line="700"/>
        <source>Capitalize only the first word of the selected text.</source>
        <translation>Капитализује само прву реч изабраног текста.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="710"/>
        <source>&amp;Quit</source>
        <translation>&amp;Напусти</translation>
    </message>
    <message>
        <location filename="../main.ui" line="713"/>
        <source>Quit</source>
        <translation>Напуштање</translation>
    </message>
    <message>
        <location filename="../main.ui" line="716"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../main.ui" line="726"/>
        <source>&amp;Special Character...</source>
        <translation>&amp;Посебни карактери...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="729"/>
        <source>Select a character to insert into your text.</source>
        <translation>Изаберите карактер који желите да уметнете у текст.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="742"/>
        <source>&amp;Numbered List</source>
        <translation>&amp;Листа под бројем</translation>
    </message>
    <message>
        <location filename="../main.ui" line="745"/>
        <source>Create a numbered list from selection.</source>
        <translation>Креира нумерисану листу од изабраног текста.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="758"/>
        <source>Bulle&amp;ted List</source>
        <translation>Лис&amp;та за набрајање</translation>
    </message>
    <message>
        <location filename="../main.ui" line="761"/>
        <source>Create a bulleted list from selection.</source>
        <translation>Креира листу набрајања од изабраног текста.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="764"/>
        <source>Ctrl+Shift+L</source>
        <translation>Ctrl+Shift+L</translation>
    </message>
    <message>
        <location filename="../main.ui" line="777"/>
        <source>Stri&amp;kethrough</source>
        <translation>Пре&amp;цртано</translation>
    </message>
    <message>
        <location filename="../main.ui" line="780"/>
        <source>Draw a line through the selected text.</source>
        <translation>Исцртава линију кроз изабрани текст.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="793"/>
        <source>&amp;Subscript</source>
        <translation>&amp;Смањи доле</translation>
    </message>
    <message>
        <location filename="../main.ui" line="796"/>
        <source>Set the selected text slightly smaller and below the normal line.</source>
        <translation>Подешава да изабрани текст буде мало мањи и испод основне линије.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="809"/>
        <source>Su&amp;perscript</source>
        <translation>Сма&amp;њи горе</translation>
    </message>
    <message>
        <location filename="../main.ui" line="812"/>
        <source>Set the selected text slightly smaller and above the normal line.</source>
        <translation>Подешава да изабрани текст буде мало мањи и изнад основне линије.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="823"/>
        <source>Zoom &amp;In</source>
        <translation>Уве&amp;ћај</translation>
    </message>
    <message>
        <location filename="../main.ui" line="826"/>
        <source>Zoom In</source>
        <translation>Увећај</translation>
    </message>
    <message>
        <location filename="../main.ui" line="829"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../main.ui" line="840"/>
        <source>Zoom &amp;Out</source>
        <translation>Сма&amp;њи</translation>
    </message>
    <message>
        <location filename="../main.ui" line="843"/>
        <source>Zoom Out</source>
        <translation>Смањи</translation>
    </message>
    <message>
        <location filename="../main.ui" line="846"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../main.ui" line="857"/>
        <source>Incre&amp;ase Indent</source>
        <translation>Уву&amp;ци напред</translation>
    </message>
    <message>
        <location filename="../main.ui" line="860"/>
        <source>Increase the indent level of the paragraph.</source>
        <translation>Увећава ниво увлачења пасуса.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="863"/>
        <source>Ctrl+Alt+M</source>
        <translation>Ctrl+Alt+M</translation>
    </message>
    <message>
        <location filename="../main.ui" line="873"/>
        <source>&amp;Decrease Indent</source>
        <translation>&amp;Увуци назад</translation>
    </message>
    <message>
        <location filename="../main.ui" line="876"/>
        <source>Decrease the indent level of the paragraph.</source>
        <translation>Умањује ниво увлачења пасуса.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="879"/>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
    <message>
        <location filename="../main.ui" line="889"/>
        <source>Split &amp;Marker</source>
        <translation>&amp;Маркер за раздвајање датотеке</translation>
    </message>
    <message>
        <location filename="../main.ui" line="892"/>
        <source>Insert Sigil split file marker</source>
        <translation>Уметни Сигил маркер за раздвајање датотеке</translation>
    </message>
    <message>
        <location filename="../main.ui" line="895"/>
        <source>Ctrl+Shift+Return</source>
        <translation>Ctrl+Shift+Return</translation>
    </message>
    <message>
        <location filename="../main.ui" line="901"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Подешавања...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="904"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../main.ui" line="910"/>
        <source>&amp;Zoom Reset</source>
        <translation>&amp;Поврати увећање</translation>
    </message>
    <message>
        <location filename="../main.ui" line="913"/>
        <source>Zoom Reset</source>
        <translation>Поврати увећање</translation>
    </message>
    <message>
        <location filename="../main.ui" line="916"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../main.ui" line="929"/>
        <source>Heading &amp;1</source>
        <translation>Наслов &amp;1</translation>
    </message>
    <message>
        <location filename="../main.ui" line="932"/>
        <source>Format paragraph as a level 1 heading.</source>
        <translation>Форматира пасус као наслов нивоа 1.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="935"/>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <location filename="../main.ui" line="948"/>
        <source>Heading &amp;2</source>
        <translation>Наслов &amp;2</translation>
    </message>
    <message>
        <location filename="../main.ui" line="951"/>
        <source>Format paragraph as a level 2 heading.</source>
        <translation>Форматира пасус као наслов нивоа 2.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="954"/>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <location filename="../main.ui" line="967"/>
        <source>Heading &amp;3</source>
        <translation>Наслов &amp;3</translation>
    </message>
    <message>
        <location filename="../main.ui" line="970"/>
        <source>Format paragraph as a level 3 heading.</source>
        <translation>Форматира пасус као наслов нивоа 3.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="973"/>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <location filename="../main.ui" line="987"/>
        <source>Heading &amp;4</source>
        <translation>Наслов &amp;4</translation>
    </message>
    <message>
        <location filename="../main.ui" line="990"/>
        <source>Format paragraph as a level 4 heading.</source>
        <translation>Форматира пасус као наслов нивоа 4.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="993"/>
        <source>Ctrl+4</source>
        <translation>Ctrl+4</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1006"/>
        <source>Heading &amp;5</source>
        <translation>Наслов &amp;5</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1009"/>
        <source>Format paragraph as a level 5 heading.</source>
        <translation>Форматира пасус као наслов нивоа 5.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1012"/>
        <source>Ctrl+5</source>
        <translation>Ctrl+5</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1025"/>
        <source>Heading &amp;6</source>
        <translation>Наслов &amp;6</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1028"/>
        <source>Format paragraph as a level 6 heading.</source>
        <translation>Форматира пасус као наслов нивоа 6.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1031"/>
        <source>Ctrl+6</source>
        <translation>Ctrl+6</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1045"/>
        <source>&amp;Normal</source>
        <translation>&amp;Нормално</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1048"/>
        <source>ormat paragraph as a normal paragraph.</source>
        <translation>Форматира пасус као нормални пасус.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1051"/>
        <source>Ctrl+7</source>
        <translation>Ctrl+7</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1061"/>
        <source>&amp;Preserve Existing Attributes</source>
        <translation>&amp;Сачувај постојеће атрибуте</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1064"/>
        <source>When applying this style, preserve any existing attributes on the tag</source>
        <translation>Када се примењује овај стил, задржи све постојеће атрибуте ознаке</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1074"/>
        <source>&amp;Select All</source>
        <translation>&amp;Изабери све</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1077"/>
        <source>Select all text in the document.</source>
        <translation>Одабира сав текст у документу.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1080"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1090"/>
        <source>&amp;Inspector</source>
        <translation>&amp;Инспектор</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1093"/>
        <source>Inspect the page.</source>
        <translation>Прегледа страницу.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1096"/>
        <source>Ctrl+F5</source>
        <translation>Ctrl+F5</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1109"/>
        <source>Find text in the page</source>
        <translation>Пронађи текст у страници</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1112"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1125"/>
        <source>Next XHtml File</source>
        <translation>Следећа XHtml датотека</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1128"/>
        <source>Next file in navigation list</source>
        <translation>Следећа датотека у листи за навигацију</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1141"/>
        <source>Previous XHtml File</source>
        <translation>Претходна XHtml датотека</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1144"/>
        <source>Previous file in navigation list</source>
        <translation>Претходна датотека у листи за навигацију</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1160"/>
        <source>Toggle between Edit and Preview Modes.</source>
        <translation>Пребацивање између режима Уређивање и Преглед</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1170"/>
        <source>About...</source>
        <translation>О...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1173"/>
        <source>Show information about PageEdit.</source>
        <translation>Приказује информације о програму ЕдиторСтранице.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1183"/>
        <source>Back to Last Link</source>
        <translation>Назад на Последњи линк</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1186"/>
        <source>Return from the last link taken</source>
        <translation>Повратак са последње употребљеног линка</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1196"/>
        <source>I&amp;D...</source>
        <translation>И&amp;Д...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1199"/>
        <source>Insert or edit an anchor with an ID name to use as a link target.</source>
        <translation>Умеће или уређује сидро са ИД именом које ће да се користи као циљ линка.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1209"/>
        <source>&amp;Link...</source>
        <translation>&amp;Веза...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1212"/>
        <source>Insert or edit an anchor with a hyperlink to a target.</source>
        <translation>Умеће или уређује сидро са хипервезом на циљ.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1222"/>
        <source>&amp;File...</source>
        <translation>&amp;Датотека...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1225"/>
        <source>Select existing image, video or audio files from your book to insert into the text.</source>
        <translation>Одаберите постојеће датотеке слика, видеа или звука из ваше књиге који треба да се уметну у текст.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1228"/>
        <source>Ctrl+Shift+I</source>
        <translation>Ctrl+Shift+I</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="750"/>
        <source>File load failed</source>
        <translation>Учитавање датотеке није било успешно</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="751"/>
        <source>File Load Failed</source>
        <translation>Неуспешно учитавање датотеке</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="846"/>
        <source>mode: Preview</source>
        <translation>режим: Преглед</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="848"/>
        <source>mode: Edit</source>
        <translation>режим: Уређивање</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1012"/>
        <source>Are you sure you want to open this link in your browser?

%1</source>
        <translation>Да ли сте сигурни да желите да отворите овај линк у свом прегледачу?

%1</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1074"/>
        <source>Do you want to save your changes before leaving?</source>
        <translation>Да ли желите да сачувате своје измене пре напуштања програма?</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1091"/>
        <source>PageEdit is closing...</source>
        <translation>ЕдиторСтранице се затвара..</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1223"/>
        <location filename="../MainWindow.cpp" line="1224"/>
        <location filename="../MainWindow.cpp" line="1225"/>
        <location filename="../MainWindow.cpp" line="1234"/>
        <location filename="../MainWindow.cpp" line="1235"/>
        <location filename="../MainWindow.cpp" line="1236"/>
        <source>HTML files (*.htm *.html *.xhtml)</source>
        <translation>HTML датотеке (*.htm *.html *.xhtml)</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1226"/>
        <source>OPF files (*.opf)</source>
        <translation>OPF датотеке (*.opf)</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1227"/>
        <source>All files (*.*)</source>
        <translation>Сви датотеке (*.*)</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1466"/>
        <source>Save File</source>
        <translation>Сачувај датотеку</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1501"/>
        <location filename="../MainWindow.cpp" line="1502"/>
        <location filename="../MainWindow.cpp" line="1514"/>
        <location filename="../MainWindow.cpp" line="1515"/>
        <source>File Save-As Failed!</source>
        <translation>Чување датотеке није успело!</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1501"/>
        <source>is not writeable</source>
        <translation>не може да се пише</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1510"/>
        <location filename="../MainWindow.cpp" line="1549"/>
        <source>File Saved</source>
        <translation>Датотека је сачувана</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1540"/>
        <location filename="../MainWindow.cpp" line="1542"/>
        <location filename="../MainWindow.cpp" line="1553"/>
        <location filename="../MainWindow.cpp" line="1554"/>
        <source>File Save Failed!</source>
        <translation>Чување датотеке није успело!</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1541"/>
        <source>does not exist or is not writeable</source>
        <translation>не постоји или не може да се пише</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1570"/>
        <source>Do not show this warning again</source>
        <translation>Не приказуј поново ово упозорење</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1571"/>
        <source>This file may not print the way you expect it to.</source>
        <translation>Ова датотека се можда неће одштампати онако како очекујете.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1572"/>
        <source>Dark backgrounds and colored text applied with an EPUB&apos;s CSS will print.</source>
        <translation>Штампаће се тамне позадине и бојени текст онако како их поставља CSS у EPUB.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1573"/>
        <source>Use caution as this can result in a lot of ink being used!</source>
        <translation>Будите опрезни јер ово може да утроши много мастила!</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1574"/>
        <source>Use the following Print Preview to see how this file will print.</source>
        <translation>Употребите следећи Преглед штампе да сазнате како ће изгледати отисак ове датотеке.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1575"/>
        <source>Check the box if you don&apos;t wish to see this warning in the future.</source>
        <translation>Штиклирајте поље ако убудуће не желите да видите ово упозорење.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1598"/>
        <source>Feature not available before Qt5.12.x</source>
        <translation>Могућност није доступна пре Qt5.12.x</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1660"/>
        <source>File Opened</source>
        <translation>Датотека отворена</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1664"/>
        <source>File Open Failed!</source>
        <translation>Отварање датотеке није успело!</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1687"/>
        <source>Clipboard contains HTML formatting</source>
        <translation>Клипборд садржи HTML форматирање</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1688"/>
        <source>Do you want to paste clipboard data as plain text?</source>
        <translation>Да ли желите да налепите податке из клипборда као чист текст?</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1764"/>
        <source>You must select text before inserting a new id.</source>
        <translation>Морате селектовати текст пре уметања новог ид.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1777"/>
        <source>ID is invalid - must start with a letter, followed by letter number _ : - or .</source>
        <translation>ИД није исправан - мора да почне словом које прати број _ : - или .</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1783"/>
        <source>You cannot insert an id at this position.</source>
        <translation>Не можете да уметнете ид на ову позицију.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1797"/>
        <source>You must select text before inserting a new link.</source>
        <translation>Морате селектовати текст пре уметања новог линка.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1810"/>
        <source>Link is invalid - cannot contain &apos;&lt;&apos; or &apos;&gt;&apos;</source>
        <translation>Линк је неисправан - не може садржати &apos;&lt;&apos; or &apos;&gt;&apos;</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1818"/>
        <source>You cannot insert a link at this position.</source>
        <translation>Не можете да уметнете линк на ову позицију.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1829"/>
        <source>Insert File</source>
        <translation>Уметни датотеку</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1873"/>
        <source>You cannot insert a media file at this position.</source>
        <translation>На ову позицију не можете да уметнете датотеку медија.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1961"/>
        <source>Do you want to save any changes before overwriting this file?</source>
        <translation>Да ли желите да сачувате измене пре преписивања овог фајла?</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../Preferences.ui" line="14"/>
        <source>Preferences</source>
        <translation>Подешавања</translation>
    </message>
    <message>
        <location filename="../Preferences.cpp" line="90"/>
        <source>PageEdit</source>
        <translation>ЕдиторСтранице</translation>
    </message>
    <message>
        <location filename="../Preferences.cpp" line="90"/>
        <source>Changes will take effect when you restart PageEdit.</source>
        <translation>Измене ће да се примене када поново покренете ЕдиторСтранице.</translation>
    </message>
    <message>
        <location filename="../Preferences.cpp" line="152"/>
        <source>Open Preferences Location</source>
        <translation>Отвори локацију подешавања</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../OPFReader.cpp" line="59"/>
        <source>Unable to read OPF file.
Line: %1 Column %2 - %3</source>
        <translation>Није могуће читање OPF датотеке.
Линија: %1 Колона %2 - %3</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="379"/>
        <source>Cannot read file %1:
%2.</source>
        <translation>Није могуће читање датотеке %1:
%2.</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="560"/>
        <source>PageEdit has encountered a problem.</source>
        <translation>ЕдиторСтранице је наишао на проблем.</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="561"/>
        <source>PageEdit may need to close.</source>
        <translation>ЕдиторСтранице можда мора да се затвори.</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="863"/>
        <source>About PageEdit</source>
        <translation>О програму ЕдиторСтранице</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="868"/>
        <source>Version</source>
        <translation>Верзија</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="869"/>
        <source>Build Date</source>
        <translation>Датум изградње</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="870"/>
        <source>Build Time</source>
        <translation>Време изградње</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="871"/>
        <source>Qt Runtime Version</source>
        <translation>Верзија Qt Извршног Окружења</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="872"/>
        <source>Qt Compiled Version</source>
        <translation>Верзија компајлираног Qt</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="873"/>
        <source>System</source>
        <translation>Систем</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="874"/>
        <source>Architecture</source>
        <translation>Архитектура</translation>
    </message>
</context>
<context>
    <name>SearchToolbar</name>
    <message>
        <location filename="../SearchToolbar.ui" line="36"/>
        <source>Search: </source>
        <translation>Претрага:</translation>
    </message>
    <message>
        <location filename="../SearchToolbar.ui" line="55"/>
        <source>Search...</source>
        <translation>Тражим...</translation>
    </message>
    <message>
        <location filename="../SearchToolbar.ui" line="88"/>
        <source>&amp;Match Case</source>
        <translation>&amp;Подудари величину слова</translation>
    </message>
    <message>
        <location filename="../SearchToolbar.cpp" line="137"/>
        <source>No results found.</source>
        <translation>Нема подударања.</translation>
    </message>
</context>
<context>
    <name>SelectCharacter</name>
    <message>
        <location filename="../SelectCharacter.ui" line="14"/>
        <source>Insert Special Character</source>
        <translation>Уметни специјални карактер</translation>
    </message>
</context>
<context>
    <name>SelectFiles</name>
    <message>
        <location filename="../SelectFiles.ui" line="14"/>
        <source>Insert File</source>
        <translation>Уметни датотеку</translation>
    </message>
    <message>
        <location filename="../SelectFiles.ui" line="46"/>
        <source>List only the file names which contain the text you enter.</source>
        <translation>Прикажи само имена датотека која садрже текст који унесете.</translation>
    </message>
    <message>
        <location filename="../SelectFiles.ui" line="49"/>
        <source>Filter:</source>
        <translation>Филтер:</translation>
    </message>
    <message>
        <location filename="../SelectFiles.ui" line="118"/>
        <source>Thumbnail size:</source>
        <translation>Величина сличица:</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="113"/>
        <source>All</source>
        <translation>Све</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="114"/>
        <source>Images</source>
        <translation>Слике</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="115"/>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="116"/>
        <source>Audio</source>
        <translation>Аудио</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="159"/>
        <source>Media Files In the Book</source>
        <translation>Датотеке медија у књизи</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="162"/>
        <source>Thumbnails</source>
        <translation>Сличице</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="325"/>
        <source>shades</source>
        <translation>нијансе</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="325"/>
        <source>colors</source>
        <translation>боје</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="326"/>
        <source>Grayscale</source>
        <translation>Сиви тонови</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="326"/>
        <source>Color</source>
        <translation>Боја</translation>
    </message>
</context>
<context>
    <name>SelectHyperlink</name>
    <message>
        <location filename="../SelectHyperlink.ui" line="14"/>
        <source>Select Target</source>
        <translation>Одабери циљ</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.ui" line="22"/>
        <source>List only the entries that match the text you enter.</source>
        <translation>Прикажи само ставке које се подударају са текстом који унесете.</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.ui" line="25"/>
        <source>Filter:</source>
        <translation>Филтер:</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.ui" line="58"/>
        <source>Enter the target URL for this hyperlink.  You can select or 
double click on existing destinations in your book from the list above.</source>
        <translation>Унесите циљни URL  за овај хиперлинк. Можете да изаберете или
урадите двоструки клик на постојећи циљ у вашој књизи из горње листе.</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.ui" line="62"/>
        <source>Target:</source>
        <translation>Циљ:</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.cpp" line="94"/>
        <source>Targets in the Book</source>
        <translation>Циљеви у књизи</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.cpp" line="95"/>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
</context>
<context>
    <name>SelectId</name>
    <message>
        <location filename="../SelectId.ui" line="14"/>
        <source>Insert ID </source>
        <translation>Уметни ИД</translation>
    </message>
    <message>
        <location filename="../SelectId.ui" line="22"/>
        <source>Enter an ID name to use as a destination for hyperlinks, notes, and TOC entries.

The dropdown box shows existing ID names in the current file.

ID names must be unique and start with a letter.</source>
        <translation>Унесите ID име које ће да се користи као циљ за хиперлинкове, белешке и ставке Садржаја.

Падајућа листа приказује постојећа ID имена у текућој датотеци.

ID имена морају бити јединствена и морају да почињу словом.</translation>
    </message>
    <message>
        <location filename="../SelectId.ui" line="29"/>
        <source>ID:</source>
        <translation>ИД:</translation>
    </message>
</context>
<context>
    <name>Utility</name>
    <message>
        <location filename="../Utility.cpp" line="656"/>
        <source>PageEdit</source>
        <translation>ЕдиторСтранице</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="657"/>
        <source>The requested file name contains non-ASCII characters. You should only use ASCII characters in filenames. Using non-ASCII characters can prevent the EPUB from working with some readers.

Continue using the requested filename?</source>
        <translation>Тражено име датотеке садржи не-ASCII карактере. У именима датотека би требало да користите само ASCII карактере. У супротном EPUB можда неће радити на свим читачима.

Да наставим да користим тражено име датотеке?</translation>
    </message>
</context>
<context>
    <name>WebViewEdit</name>
    <message>
        <location filename="../WebViewEdit.cpp" line="167"/>
        <source>No suggestions</source>
        <translation>Нема сугестија</translation>
    </message>
    <message>
        <location filename="../WebViewEdit.cpp" line="179"/>
        <source>Check Spelling</source>
        <translation>Провера правописа</translation>
    </message>
    <message>
        <location filename="../WebViewEdit.cpp" line="188"/>
        <source>Select Language</source>
        <translation>Изаберите језик</translation>
    </message>
</context>
</TS>